gracetools.GraceContainer
=========================

.. inheritance-diagram:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer
   :private-bases:

.. autoclass:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.contents_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.duration_in_seconds

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.leaves

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.lilypond_format

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.music

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.preprolated_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.is_parallel

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.kind

Methods
-------

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.append

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.detach

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.extend

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.index

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.insert

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.pop

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.remove

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__add__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__call__

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__contains__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__delitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__getitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__iadd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__imul__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__len__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__radd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__repr__

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.gracetools.GraceContainer.GraceContainer.GraceContainer.__setitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`
